
*=========
* Results 
*=========

*==========================
* Table 2 - Ordered Probit
*==========================
use "$works/base_vf.dta", clear //tiene com_08

gen c_age=age/100
gen c2_age=(age/100)^2
gen c_sch=sch/100
gen c_nkids06 =nkids06/10
gen c_nkids717=nkids717/10

global ind    "c_age c.c_age#c.c_age i.male c.c_sch i.couple c.c_nkids06 c.c_nkids717"
global wage   "lwage"
global work   "i.h_skill i.m_skill"
global sector "i.secundario i.terciario"
global geo    "i.r_norte i.r_sur i.urban"

eststo m9: quietly oprobit SAH logdist $ind $wage $work $sector $geo, rob 
drop if _est_m9==0

sum dist
scalar dist_mean=r(mean)
scalar list dist_mean

sum time
scalar time_mean=r(mean)
scalar list time_mean

sum wage
scalar wage_mean = r(mean)
scalar list wage_mean

set more off

eststo m1: quietly oprobit SAH logdist $ind $wage $work $sector $geo, rob
estadd fitstat
eststo margin1: margins, dydx(*) predict(outcome(5)) post
estimates store margin1, title(Model 1)

estadd scalar VC1= - (_b[logdist]/_b[lwage])
testnl -(_b[logdist]/_b[lwage])=0
estadd scalar pvalue_ratio=r(p)
estadd scalar VC2= - (_b[logdist]*wage_mean)/(_b[lwage]*dist_mean) 

esttab m1 margin1 using "$outputs/Table 2 - Ordered Probit.csv", /// 
		replace label title("Probit Ordenado: SAH - Log of distance -- Marginal Effects Pr(SAH = 5)") ///
        b(3) se(3) stats(N r2_p aic0 bic0 VC1 pvalue_ratio VC2, /// 
        fmt(0 3 3 3 3 3) ///  
		labels("Observations" "Pseudo R2" "AIC" "BIC")) ///
		drop(0.male 0.couple 0.h_skill 0.m_skill 0.secundario 0.terciario 0.r_norte 0.r_sur 0.urban) ///
		star(* 0.10 ** 0.05 *** 0.01) ///
        mtitle("Model 1" "ME/se") ///
		note("Standard errors in parentheses - ME: SE computed using Delta Method")		
		
		
		
		
*==================	
* Marginal effects
*==================		
set more off
global ind    "age c.age#c.age i.male c.sch i.couple c.nkids06 c.nkids717"


* Figure 4. Marginal Effects Ordered Probit Pr(SAH = 5)
*===========================================================================
set more off
oprobit SAH logdist $wage $ind $work $sector $geo, rob 
margins, dydx(*) predict(outcome(5)) atmeans 
marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) graphregion(color(white)) allx ///
			 title("Marginal Effects Pr(SAH=5)", col(black)) ytitle("Variables") xtitle("") ///
			 ylabel(, nogrid)
graph export "$graphs/Figure4.eps", as(eps) replace


* Appendix: Figure 9. Marginal Effects Ordered Probit on Pr(SAH=j), j=1, 2, 3, 4
*=================================================================================
set more off
oprobit SAH logdist $wage $ind $work $sector $geo, rob 
margins, dydx(*) predict(outcome(4)) atmeans
marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) graphregion(color(white)) allx ///
			 title("Marginal Effects Pr(SAH=4)") ytitle("Variables") xtitle("") ///
			 ylabel(, nogrid) name(op4, replace)
			 

set more off
oprobit SAH logdist $wage $ind $work $sector $geo, rob 
margins, dydx(*) predict(outcome(3)) atmeans
marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) graphregion(color(white)) allx ///
			 title("Marginal Effects Pr(SAH=3)") ytitle("Variables") xtitle("") ///
			 ylabel(, nogrid) name(op3, replace)			 

			 
set more off
oprobit SAH logdist $wage $ind $work $sector $geo, rob 
margins, dydx(*) predict(outcome(2)) atmeans
marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) graphregion(color(white)) allx ///
			 title("Marginal Effects Pr(SAH=2)") ytitle("Variables") xtitle("") ///
			 ylabel(, nogrid) name(op2, replace)			 

			 
set more off
oprobit SAH logdist $wage $ind $work $sector $geo, rob 
margins, dydx(*) predict(outcome(1)) atmeans
marginsplot, horizontal unique xline(0) recast(scatter) yscale(reverse) graphregion(color(white)) allx ///
			 title("Marginal Effects Pr(SAH=1)") ytitle("Variables") xtitle("") ///
			 ylabel(, nogrid) name(op1, replace)		 

graph combine op1 op2 op3 op4, graphregion(color(white))
graph export "$graphs/Figure9.eps", as(eps) replace



* Figure 5. Confidence Intervals for WTA (commuting distance in kilometers)
*===========================================================================
set more off
eststo d99: oprobit SAH logdist $ind $wage $work $sector $geo, rob 
margins, expression((-(_b[logdist])*wage_mean)/(_b[lwage]*dist_mean)) post vce(delta) level(99)

eststo d95: oprobit SAH logdist $ind $wage $work $sector $geo, rob 
margins, expression((-(_b[logdist])*wage_mean)/(_b[lwage]*dist_mean)) post vce(delta) level(95)

eststo d90: oprobit SAH logdist $ind $wage $work $sector $geo, rob
margins, expression((-(_b[logdist])*wage_mean)/(_b[lwage]*dist_mean)) post vce(delta) level(90)


set more off
preserve
use "$inputs/WTA_distance.dta", clear

mkmat y upper_90 lower_90 upper_95 lower_95, matrix(y90mat)
mat list y90mat

coefplot (matrix(y90mat[,1]), ci((y90mat[,2] y90mat[,3]) (y90mat[,4] y90mat[,5])) ///
		  msymbol(d) mfcolor(white) graphregion(color(white)) ///
		  xline(0, lpattern(--) lwidth(vthin) lcolor(black))), ///
		  ylabel(1 "OP model" 2 "Class 1" 3 "Class 2", nogrid) xlabel(,labsize(vsmall)) ///
		  legend(order(1 "90" 2 "95" 3 " ") row(1) region(lcolor(white)))
graph export "$graphs/Figure5.eps", as(eps) replace
restore



* Tables 3. Distancia ¿Cuales son los que más conmutan (pares)?
*===============================================================
preserve
keep if dist>80		  
br codcom_c codcom_v commute dist
bys codcom_v codcom_c: egen n_com=sum(commute)
sort n_com
gen n=1
bys codcom_v: egen n_tot=sum(n)
gen tas_com=n_com/n_tot
sort tas_com
duplicates drop codcom_v codcom_c, force
sort n_com 
restore 



* Figure 6. Confidence Intervals for WTA (commuting time in minutes)
*=====================================================================
set more off
eststo t99: oprobit SAH logtime $ind $wage $work $sector $geo, rob 
margins, expression((-(_b[logtime])*wage_mean)/(_b[lwage]*time_mean)) post vce(delta) level(99)

eststo t95: oprobit SAH logtime $ind $wage $work $sector $geo, rob 
margins, expression((-(_b[logtime])*wage_mean)/(_b[lwage]*time_mean)) post vce(delta) level(95)

eststo t90: oprobit SAH logtime $ind $wage $work $sector $geo, rob
margins, expression((-(_b[logtime])*wage_mean)/(_b[lwage]*time_mean)) post vce(delta) level(90)

preserve
set more off
use "$inputs/WTA_time.dta", clear

mkmat y upper_90 lower_90 upper_95 lower_95, matrix(y_time)
mat list y_time

coefplot (matrix(y_time[,1]), ci((y_time[,2] y_time[,3]) (y_time[,4] y_time[,5])) ///
		  msymbol(d) mfcolor(white) graphregion(color(white)) ///
		  xline(0, lpattern(--) lwidth(vthin) lcolor(black))), ///
		  ylabel(1 "OP model" 2 "Class 1" 3 "Class 2", nogrid) xlabel(,labsize(vsmall)) ///
		  legend(order(1 "90" 2 "95" 3 " ") row(1) region(lcolor(white)))
graph export "$graphs/Figure6.eps", as(eps) replace
restore


* Figure 8. Confidence Intervals for WTA using functional areas (commuting distance in kilometers)
*==================================================================================================
set more off
gen d_age=age/10
gen d2_age=(age/10)^2
gen d_sch=sch/10

global ind    "d_age c.d_age#c.d_age i.male c.d_sch i.couple c.c_nkids06 c.c_nkids717"

keep if conm_af==1

sum dist_af
scalar dist_af_mean=r(mean)
scalar list dist_af_mean

sum wage
scalar wage_mean = r(mean)
scalar list wage_mean

eststo daf99: oprobit SAH logdist_af $ind $wage $work $sector $geo, rob 
margins, expression((-(_b[logdist])*wage_mean)/(_b[lwage]*dist_af_mean)) post vce(delta) level(99)

eststo daf95: oprobit SAH logdist_af $ind $wage $work $sector $geo, rob 
margins, expression((-(_b[logdist])*wage_mean)/(_b[lwage]*dist_af_mean)) post vce(delta) level(95)

eststo daf90: oprobit SAH logdist_af $ind $wage $work $sector $geo, rob
margins, expression((-(_b[logdist])*wage_mean)/(_b[lwage]*dist_af_mean)) post vce(delta) level(90)


preserve
set more off
use "$inputs/WTA_distaf.dta", clear

mkmat y upper_90 lower_90 upper_95 lower_95, matrix(y_af)
mat list y_af

coefplot (matrix(y_af[,1]), ci((y_af[,2] y_af[,3]) (y_af[,4] y_af[,5])) ///
		  msymbol(d) mfcolor(white) graphregion(color(white)) ///
		  ylabel(,nogrid) ///
		  xline(0, lpattern(--) lwidth(vthin) lcolor(black))), ///
		  ylabel(1 "OP model" 2 "Class 1" 3 "Class 2", nogrid)  legend(order(1 "90" 2 "95" 3 " ") row(1))
graph export "$graphs/Figure8.eps", as(eps) replace
restore







